WebPersistenceOption class
How data is persisted on the Web platform.
- Inheritance
-
- Object
- EnumClass
- WebPersistenceOption
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
WebPersistenceOption> -
The WebPersistenceOption serializer.
no setter
-
values
→ BuiltSet<
WebPersistenceOption> -
All values of WebPersistenceOption.
no setter
Static Methods
-
valueOf(
String name) → WebPersistenceOption -
Gets the WebPersistenceOption value corresponding to
name.
Constants
- indexedDB → const WebPersistenceOption
- Data will be stored in browser storage using IndexedDB.
- inMemory → const WebPersistenceOption
- NOTE: Hosted UI is not supported for this option, currently.