inMemory constant

WebPersistenceOption const inMemory

NOTE: Hosted UI is not supported for this option, currently.

Data will be stored in memory and will never be written to disk.

Data will not be shared across tabs or windows, and all data will be lost when the window is closed or page is refreshed.

Implementation

static const WebPersistenceOption inMemory = _$inMemory;