IOSSecureStorageOptions class abstract
Configuration options that are specific to iOS.
Constructors
- IOSSecureStorageOptions({KeychainAttributeAccessible accessible = KeychainAttributeAccessible.accessibleAfterFirstUnlockThisDeviceOnly, String? accessGroup})
-
Configuration options that are specific to iOS.
factory
Properties
- accessGroup → String?
-
Sets the kSecAttrAccessGroup
attribute for all Keychain operations.
no setter
- accessible → KeychainAttributeAccessible?
-
Sets the kSecAttrAccessible
attribute for all Keychain operations.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(IOSSecureStorageOptionsBuilder)) → IOSSecureStorageOptions -
Rebuilds the instance.
inherited
-
toBuilder(
) → IOSSecureStorageOptionsBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
IOSSecureStorageOptions> -
The IOSSecureStorageOptions serializer.
no setter